PdfAnnotBase class abstract

Implementers

Constructors

PdfAnnotBase({required String subtype, required PdfRect rect, PdfBorder? border, String? content, String? name, Set<PdfAnnotFlags>? flags, DateTime? date, PdfColor? color, String? subject, String? author})

Properties

author → String?
The author of the annotation
final
border → PdfBorder?
the border for this annotation
final
color → PdfColor?
Color
final
content → String?
The text of a text annotation
final
date → DateTime?
Last modification date
final
flags ↔ Set<PdfAnnotFlags>
Flags specifying various characteristics of the annotation
latefinal
flagValue → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The internal name for a link
final
rect → PdfRect
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
The subject of the annotation
final
subtype → String
The subtype of the outline, ie text, note, etc
final

Methods

appearance(PdfDocument pdfDocument, PdfAnnotAppearance type, {String? name, Matrix4? matrix, PdfRect? boundingBox, bool selected = false}) → PdfGraphics
build(PdfPage page, PdfObject<PdfDataType> object, PdfDict<PdfDataType> params) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited