PdfAnnotInk class

Inheritance

Constructors

PdfAnnotInk(PdfDocument document, List<List<PdfPoint>> points, {required PdfRect rect, PdfBorder? border, Set<PdfAnnotFlags>? flags, DateTime? date, PdfColor? color, String? subject, String? author, String? content})
Create an Ink List annotation

Properties

author → String?
The author of the annotation
finalinherited
border → PdfBorder?
the border for this annotation
finalinherited
color → PdfColor?
Color
finalinherited
content → String?
The text of a text annotation
finalinherited
date → DateTime?
Last modification date
finalinherited
document → PdfDocument
final
flags ↔ Set<PdfAnnotFlags>
Flags specifying various characteristics of the annotation
latefinalinherited
flagValue → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The internal name for a link
finalinherited
points → List<List<PdfPoint>>
final
rect → PdfRect
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
The subject of the annotation
finalinherited
subtype → String
The subtype of the outline, ie text, note, etc
finalinherited

Methods

appearance(PdfDocument pdfDocument, PdfAnnotAppearance type, {String? name, Matrix4? matrix, PdfRect? boundingBox, bool selected = false}) → PdfGraphics
inherited
build(PdfPage page, PdfObject<PdfDataType> object, PdfDict<PdfDataType> params) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited