PdfChoiceField class

Inheritance

Constructors

PdfChoiceField({required PdfRect rect, required PdfColor textColor, required PdfFont font, required double fontSize, required List<String> items, String? fieldName, String? value, String? defaultValue})

Properties

author → String?
The author of the annotation
finalinherited
backgroundColor → PdfColor?
finalinherited
border → PdfBorder?
the border for this annotation
finalinherited
color → PdfColor?
Color
finalinherited
content → String?
The text of a text annotation
finalinherited
date → DateTime?
Last modification date
finalinherited
defaultValue → String?
final
fieldFlags → Set<PdfFieldFlags>?
final
fieldFlagsValue → int
no setter
fieldName → String?
finalinherited
fieldType → String
finalinherited
flags ↔ Set<PdfAnnotFlags>
Flags specifying various characteristics of the annotation
latefinalinherited
flagValue → int
no setterinherited
font → PdfFont
final
fontSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
highlighting → PdfAnnotHighlighting?
finalinherited
items → List<String>
final
name → String?
The internal name for a link
finalinherited
rect → PdfRect
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
The subject of the annotation
finalinherited
subtype → String
The subtype of the outline, ie text, note, etc
finalinherited
textColor → PdfColor
final
value → String?
final

Methods

appearance(PdfDocument pdfDocument, PdfAnnotAppearance type, {String? name, Matrix4? matrix, PdfRect? boundingBox, bool selected = false}) → PdfGraphics
inherited
build(PdfPage page, PdfObject<PdfDataType> object, PdfDict<PdfDataType> params) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited