PdfColorCmyk class

Represents an CMYK color

Inheritance

Constructors

PdfColorCmyk(double cyan, double magenta, double yellow, double black, [double a = 1.0])
Creates a CMYK color
const
PdfColorCmyk.fromRgb(double r, double g, double b, [double a = 1.0])
Create a CMYK color from red ,green and blue components
const

Properties

alpha → double
Opacity
finalinherited
analagous → List<PdfColor>
Returns a list of analagous colors
no setterinherited
black → double
Black component
final
blue → double
Blue component
finalinherited
complementary → PdfColor
Get a complementary color with hue shifted by -120°
no setterinherited
cyan → double
Cyan component
final
green → double
Green component
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isDark → bool
Determines whether the given PdfColor is dark.
no setterinherited
isLight → bool
Determines whether the given PdfColor is light.
no setterinherited
luminance → double
Get the luminance
no setterinherited
magenta → double
Magenta component
final
monochromatic → List<PdfColor>
Get some similar colors
no setterinherited
red → double
Red component
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splitcomplementary → List<PdfColor>
Returns a list of complementary colors
no setterinherited
tetradic → List<PdfColor>
Returns a list of tetradic colors
no setterinherited
triadic → List<PdfColor>
Returns a list of triadic colors
no setterinherited
yellow → double
Yellow component
final

Methods

flatten({PdfColor background = const PdfColor(1, 1, 1)}) → PdfColor
Apply the color transparency by updating the color values according to a background color.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shade(double strength) → PdfColor
Build a Material Color shade using the given strength.
inherited
toCmyk() → PdfColorCmyk
Convert this color to CMYK
override
toHex() → String
Get an Hexadecimal representation of this color
inherited
toHsl() → PdfColorHsl
Convert this color to HSL
inherited
toHsv() → PdfColorHsv
Convert this color to HSV
inherited
toInt() → int
Get the int32 representation of this color
inherited
toString() → String
A string representation of this object.
override
withAlpha(double alpha) → PdfColor
Create a copy of this color with a different alpha value
inherited
withBlue(double blue) → PdfColor
Create a copy of this color with a different blue value
inherited
withGreen(double green) → PdfColor
Create a copy of this color with a different green value
inherited
withRed(double red) → PdfColor
Create a copy of this color with a different red value
inherited
withValues(double? alpha, double? red, double? green, double? blue) → PdfColor
Create a copy of this color with different values
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited