PdfColorHsl class

Represents an HSL color

Inheritance

Constructors

PdfColorHsl(double hue, double saturation, double lightness, [double alpha = 1.0])
Creates an HSL color
factory
PdfColorHsl.fromRgb(double red, double green, double blue, [double alpha = 1.0])
Creates an HSL color from red, green, and blue components
factory

Properties

alpha → double
Opacity
finalinherited
analagous → List<PdfColor>
Returns a list of analagous colors
no setterinherited
blue → double
Blue component
finalinherited
complementary → PdfColor
Get a complementary color with hue shifted by -120°
no setterinherited
green → double
Green component
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hue → double
Hue component
final
isDark → bool
Determines whether the given PdfColor is dark.
no setterinherited
isLight → bool
Determines whether the given PdfColor is light.
no setterinherited
lightness → double
Lightness component
final
luminance → double
Get the luminance
no setterinherited
monochromatic → List<PdfColor>
Get some similar colors
no setterinherited
red → double
Red component
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saturation → double
Saturation component
final
splitcomplementary → List<PdfColor>
Returns a list of complementary colors
no setterinherited
tetradic → List<PdfColor>
Returns a list of tetradic colors
no setterinherited
triadic → List<PdfColor>
Returns a list of triadic colors
no setterinherited

Methods

flatten({PdfColor background = const PdfColor(1, 1, 1)}) → PdfColor
Apply the color transparency by updating the color values according to a background color.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shade(double strength) → PdfColor
Build a Material Color shade using the given strength.
inherited
toCmyk() → PdfColorCmyk
Convert this color to CMYK
inherited
toHex() → String
Get an Hexadecimal representation of this color
inherited
toHsl() → PdfColorHsl
Convert this color to HSL
override
toHsv() → PdfColorHsv
Convert this color to HSV
inherited
toInt() → int
Get the int32 representation of this color
inherited
toString() → String
A string representation of this object.
override
withAlpha(double alpha) → PdfColor
Create a copy of this color with a different alpha value
inherited
withBlue(double blue) → PdfColor
Create a copy of this color with a different blue value
inherited
withGreen(double green) → PdfColor
Create a copy of this color with a different green value
inherited
withHue(double hue) → PdfColorHsl
Create a copy of this HSL color with a different hue value
withLightness(double lightness) → PdfColorHsl
Create a copy of this HSL color with a different lightness value
withRed(double red) → PdfColor
Create a copy of this color with a different red value
inherited
withSaturation(double saturation) → PdfColorHsl
Create a copy of this HSL color with a different saturation value
withValues(double? alpha, double? red, double? green, double? blue) → PdfColor
Create a copy of this color with different values
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited