PdfColorHsv class

Same as HSB, Cylindrical geometries with hue, their angular dimension, starting at the red primary at 0°, passing through the green primary at 120° and the blue primary at 240°, and then wrapping back to red at 360°

Inheritance

Constructors

PdfColorHsv(double hue, double saturation, double value, [double alpha = 1.0])
Creates an HSV color
factory
PdfColorHsv.fromRgb(double red, double green, double blue, [double alpha = 1.0])
Creates an HSV color from red, green, blue components
factory

Properties

alpha → double
Opacity
finalinherited
analagous → List<PdfColorHsv>
Returns a list of analagous colors
no setteroverride
blue → double
Blue component
finalinherited
complementary → PdfColorHsv
Get a complementary color with hue shifted by -120°
no setteroverride
green → double
Green component
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hue → double
Angular position the colorspace coordinate diagram in degrees from 0° to 360°
final
isDark → bool
Determines whether the given PdfColor is dark.
no setterinherited
isLight → bool
Determines whether the given PdfColor is light.
no setterinherited
luminance → double
Get the luminance
no setterinherited
monochromatic → List<PdfColorHsv>
Get a similar color
no setteroverride
red → double
Red component
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saturation → double
Saturation of the color
final
splitcomplementary → List<PdfColorHsv>
Get two complementary colors with hue shifted by -120°
no setteroverride
tetradic → List<PdfColorHsv>
Returns a list of tetradic colors
no setteroverride
triadic → List<PdfColorHsv>
Returns a list of triadic colors
no setteroverride
value → double
Brightness
final

Methods

flatten({PdfColor background = const PdfColor(1, 1, 1)}) → PdfColor
Apply the color transparency by updating the color values according to a background color.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shade(double strength) → PdfColor
Build a Material Color shade using the given strength.
inherited
toCmyk() → PdfColorCmyk
Convert this color to CMYK
inherited
toHex() → String
Get an Hexadecimal representation of this color
inherited
toHsl() → PdfColorHsl
Convert this color to HSL
inherited
toHsv() → PdfColorHsv
Convert this color to HSV
override
toInt() → int
Get the int32 representation of this color
inherited
toString() → String
A string representation of this object.
override
withAlpha(double alpha) → PdfColor
Create a copy of this color with a different alpha value
inherited
withBlue(double blue) → PdfColor
Create a copy of this color with a different blue value
inherited
withGreen(double green) → PdfColor
Create a copy of this color with a different green value
inherited
withHue(double hue) → PdfColorHsv
Create a copy of this HSV color with a different hue value
withRed(double red) → PdfColor
Create a copy of this color with a different red value
inherited
withSaturation(double saturation) → PdfColorHsv
Create a copy of this HSV color with a different saturation value
withValue(double value) → PdfColorHsv
Create a copy of this HSV color with a different value (brightness) value
withValues(double? alpha, double? red, double? green, double? blue) → PdfColor
Create a copy of this color with different values
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited