PdfDocumentParserBase class abstract

Base class for loading an existing PDF document.

Constructors

PdfDocumentParserBase(Uint8List bytes)
Create a Document loader instance

Properties

bytes → Uint8List
The existing PDF document content
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
The objects size of the existing PDF document
no setter
version → PdfVersion
no setter
xrefOffset → int
The offset of the previous cross reference table
no setter

Methods

mergeDocument(PdfDocument pdfDocument) → void
Import the existing objects into the new PDF document
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited