PdfFontMetrics class

Describe dimensions for glyphs in a font

Annotations
  • @immutable

Constructors

PdfFontMetrics({required double left, required double top, required double right, required double bottom, double? ascent, double? descent, double? advanceWidth, double? leftBearing})
Create a PdfFontMetrics object
const
PdfFontMetrics.append(Iterable<PdfFontMetrics> metrics, {double letterSpacing = 0})
Add another metric
factory

Properties

advanceWidth → double
distance to move right to draw the next glyph
final
ascent → double
Spans the distance between the baseline and the top of the glyph that reaches farthest from the baseline
final
bottom → double
Bottom most of the bounding box
final
descent → double
Spans the distance between the baseline and the lowest descending glyph
final
effectiveLeft → double
Real left position. The glyph may overflow on the left
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → double
Height of the glyph
no setter
left → double
Left most of the bounding box
final
leftBearing → double
Starting point
final
maxHeight → double
Maximum Height any glyph from this font can have
no setter
maxWidth → double
Maximum Width any glyph from this font can have
no setter
Right most of the bounding box
final
rightBearing → double
Ending point
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → PdfPoint
Get the unit size of this string
no setter
top → double
Top most of the bounding box
final
width → double
Width of the glyph
no setter

Methods

copyWith({double? left, double? top, double? right, double? bottom, double? ascent, double? descent, double? advanceWidth, double? leftBearing}) → PdfFontMetrics
Make a copy of this object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPdfRect() → PdfRect
Get the bounding box
toString() → String
A string representation of this object.
override

Operators

operator *(double factor) → PdfFontMetrics
Multiply this metrics object with a font size
operator ==(Object other) → bool
The equality operator.
inherited

Constants

zero → const PdfFontMetrics
Zero-sized dimensions