PdfGraphicState class

Graphic state

Annotations
  • @immutable

Constructors

PdfGraphicState({double? opacity, double? strokeOpacity, double? fillOpacity, PdfBlendMode? blendMode, PdfSoftMask? softMask, PdfFunction? transferFunction})
Create a new graphic state
const

Properties

blendMode → PdfBlendMode?
The current blend mode to be used
final
fillOpacity → double?
Fill opacity to apply to this graphic state
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softMask → PdfSoftMask?
Opacity mask
final
strokeOpacity → double?
Stroke opacity to apply to this graphic state
final
transferFunction → PdfFunction?
Color transfer function
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output() → PdfDict<PdfDataType>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override