PdfName class

Constructors

PdfName(String value)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output(PdfObjectBase<PdfDataType> o, PdfStream s, [int? indent]) → void
toList() → Uint8List
inherited
toString([int? indent]) → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override