PdfOutline class

Pdf Outline object

Constructors

PdfOutline(PdfDocument pdfDocument, {String? title, PdfPage? dest, PdfRect? rect, String? anchor, PdfColor? color, PdfOutlineMode destMode = PdfOutlineMode.fitPage, PdfOutlineStyle style = PdfOutlineStyle.normal, PdfPage? page})
Constructs a Pdf Outline object. When selected, the specified region is displayed.

Properties

anchor → String?
Named destination
final
color → PdfColor?
Color of the outline text
final
dest ↔ PdfPage?
The destination page
getter/setter pair
destMode → PdfOutlineMode
How the destination is handled
final
effectiveLevel ↔ int?
External level for this outline
getter/setter pair
elapsedStopwatch → int
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
inUse ↔ bool
getter/setter pairinherited
objgen → int
This is the generation number for this object.
finalinherited
objser → int
This is the unique serial number for this object.
finalinherited
outlines ↔ List<PdfOutline>
This holds any outlines below us
getter/setter pair
page → String?
Page number
no setter
params → PdfDict<PdfDataType>
finalinherited
parent ↔ PdfOutline?
For subentries, this points to it's parent outline
getter/setter pair
pdfDocument → PdfDocument
This allows any Pdf object to refer to the document being constructed.
finalinherited
rect → PdfRect?
The region on the destination page
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → PdfSettings
finalinherited
size ↔ int
getter/setter pairinherited
style → PdfOutlineStyle
How to display the outline text
final
title → String?
This is this outlines Title
final

Methods

add(PdfOutline outline) → void
This method creates an outline, and attaches it to this one. When the outline is selected, the supplied region is displayed.
debugFill(String value) → void
inherited
descendants() → int
Returns the total number of descendants below this one.
getIndex(PdfOutline outline) → int
This is called by children to find their position in this outlines tree.
getLast() → int
Returns the last index in this outline
getNode(int i) → PdfOutline
Returns the outline at a specified position.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output(PdfStream s) → int
inherited
prepare() → void
Prepare the object to be written to the stream
ref() → PdfIndirect
Returns the unique serial number in Pdf format
inherited
setInsertion(PdfStream os, [int size = _maxSize]) → void
inherited
startStopwatch() → void
inherited
stopStopwatch() → void
inherited
toString() → String
A string representation of this object.
writeContent(PdfStream s) → void
inherited
writeDebug(PdfStream os) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited