PdfPageFormat class

Constructors

PdfPageFormat(double width, double height, {double marginTop = 0.0, double marginBottom = 0.0, double marginLeft = 0.0, double marginRight = 0.0, double? marginAll})
const

Properties

availableDimension → PdfPoint
Total page dimensions excluding margins
no setter
availableHeight → double
Total page height excluding margins
no setter
availableWidth → double
Total page width excluding margins
no setter
dimension → PdfPoint
Total page dimensions
no setter
hashCode → int
The hash code for this object.
no setteroverride
height → double
final
landscape → PdfPageFormat
no setter
marginBottom → double
final
marginLeft → double
final
marginRight → double
final
marginTop → double
final
portrait → PdfPageFormat
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final

Methods

applyMargin({required double left, required double top, required double right, required double bottom}) → PdfPageFormat
copyWith({double? width, double? height, double? marginTop, double? marginBottom, double? marginLeft, double? marginRight}) → PdfPageFormat
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

a3 → const PdfPageFormat
a4 → const PdfPageFormat
a5 → const PdfPageFormat
a6 → const PdfPageFormat
cm → const double
dp → const double
Flutter's Logical Pixel
inch → const double
letter → const PdfPageFormat
mm → const double
point → const double
roll57 → const PdfPageFormat
roll80 → const PdfPageFormat
standard → const PdfPageFormat
undefined → const PdfPageFormat