PdfShading class

Constructors

PdfShading(PdfDocument pdfDocument, {required PdfShadingType shadingType, required PdfBaseFunction function, required PdfPoint start, required PdfPoint end, double? radius0, double? radius1, PdfRect? boundingBox, bool extendStart = false, bool extendEnd = false})

Properties

boundingBox → PdfRect?
final
elapsedStopwatch → int
no setterinherited
end → PdfPoint
final
extendEnd → bool
final
extendStart → bool
final
function → PdfBaseFunction
final
hashCode → int
The hash code for this object.
no setterinherited
inUse ↔ bool
getter/setter pairinherited
name → String
Name of the Shading object
no setter
objgen → int
This is the generation number for this object.
finalinherited
objser → int
This is the unique serial number for this object.
finalinherited
params → PdfDict<PdfDataType>
finalinherited
pdfDocument → PdfDocument
This allows any Pdf object to refer to the document being constructed.
finalinherited
radius0 → double?
final
radius1 → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → PdfSettings
finalinherited
shadingType → PdfShadingType
final
size ↔ int
getter/setter pairinherited
start → PdfPoint
final

Methods

debugFill(String value) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output(PdfStream s) → int
inherited
prepare() → void
Prepare the object to be written to the stream
ref() → PdfIndirect
Returns the unique serial number in Pdf format
inherited
setInsertion(PdfStream os, [int size = _maxSize]) → void
inherited
startStopwatch() → void
inherited
stopStopwatch() → void
inherited
toString() → String
A string representation of this object.
inherited
writeContent(PdfStream s) → void
inherited
writeDebug(PdfStream os) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited