PdfSignature class

Constructors

PdfSignature(PdfDocument pdfDocument, {required PdfSignatureBase value, required Set<PdfSigFlags> flags, List<Uint8List>? crl, List<Uint8List>? cert, List<Uint8List>? ocsp})

Properties

cert → List<PdfObjectStream>
final
crl → List<PdfObjectStream>
final
elapsedStopwatch → int
no setterinherited
flags → Set<PdfSigFlags>
final
flagsValue → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
inUse ↔ bool
getter/setter pairinherited
objgen → int
This is the generation number for this object.
finalinherited
objser → int
This is the unique serial number for this object.
finalinherited
ocsp → List<PdfObjectStream>
final
params → PdfDict<PdfDataType>
finalinherited
pdfDocument → PdfDocument
This allows any Pdf object to refer to the document being constructed.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → PdfSettings
finalinherited
size ↔ int
getter/setter pairinherited
value → PdfSignatureBase
final

Methods

debugFill(String value) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output(PdfStream s) → int
prepare() → void
Prepare the object to be written to the stream
inherited
ref() → PdfIndirect
Returns the unique serial number in Pdf format
inherited
setInsertion(PdfStream os, [int size = _maxSize]) → void
inherited
startStopwatch() → void
inherited
stopStopwatch() → void
inherited
toString() → String
A string representation of this object.
inherited
writeContent(PdfStream s) → void
inherited
writeDebug(PdfStream os) → void
inherited
writeSignature(PdfStream os) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited