PdfSignatureBase class abstract

Constructors

PdfSignatureBase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasMDP → bool
Modification detection and prevention
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preSign(PdfObject<PdfDataType> object, PdfDict<PdfDataType> params) → void
sign(PdfObject<PdfDataType> object, PdfStream os, PdfDict<PdfDataType> params, int? offsetStart, int? offsetEnd) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited