PdfSoftMask class

Constructors

PdfSoftMask(PdfDocument document, {required PdfRect boundingBox, bool isolated = false, bool knockout = false, bool invert = false})

Properties

document → PdfDocument
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getGraphics() → PdfGraphics?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output() → PdfDict<PdfDataType>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited