PdfTtfFont class

Inheritance

Constructors

PdfTtfFont(PdfDocument pdfDocument, ByteData bytes, {bool protect = false})
Constructs a PdfTtfFont

Properties

ascent → double
Spans the distance between the baseline and the top of the glyph that reaches farthest from the baseline
no setteroverride
descent → double
Spans the distance between the baseline and the lowest descending glyph
no setteroverride
descriptor ↔ PdfFontDescriptor
getter/setter pair
elapsedStopwatch → int
no setterinherited
emptyLineHeight → double
Height of an empty line
no setterinherited
file ↔ PdfObjectStream
getter/setter pair
font → TtfParser
final
fontName → String
The font's real name
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
inUse ↔ bool
getter/setter pairinherited
isCidFont → bool
Whether this font is written as a CID /Type0 font.
no setter
name → String
Internal name
no setterinherited
objgen → int
This is the generation number for this object.
finalinherited
objser → int
This is the unique serial number for this object.
finalinherited
params → PdfDict<PdfDataType>
finalinherited
pdfDocument → PdfDocument
This allows any Pdf object to refer to the document being constructed.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → PdfSettings
finalinherited
size ↔ int
getter/setter pairinherited
subtype → String
The df type of the font, usually /Type1
no setteroverride
unicodeCMap ↔ PdfUnicodeCmap
getter/setter pair
unitsPerEm → int
Internal units per
no setteroverride
widthsObject ↔ PdfObject<PdfArray<PdfDataType>>
getter/setter pair

Methods

debugFill(String value) → void
inherited
glyphMetrics(int charCode) → PdfFontMetrics
Calculate the PdfFontMetrics for this glyph
override
isRuneSupported(int charCode) → bool
is this Rune supported by this font
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
output(PdfStream s) → int
inherited
prepare() → void
Prepare the object to be written to the stream
override
putText(PdfStream stream, String text) → void
Draw some text
override
ref() → PdfIndirect
Returns the unique serial number in Pdf format
inherited
setInsertion(PdfStream os, [int size = _maxSize]) → void
inherited
startStopwatch() → void
inherited
stopStopwatch() → void
inherited
stringMetrics(String s, {double letterSpacing = 0}) → PdfFontMetrics
Calculate the PdfFontMetrics for this string
override
stringSize(String s) → PdfPoint
Calculate the unit size of this string
inherited
toString() → String
A string representation of this object.
inherited
writeContent(PdfStream s) → void
inherited
writeDebug(PdfStream os) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited