PdfaAttachedFile class

Constructors

PdfaAttachedFile({required String name, required String data, String subType = '/text/xml', @Deprecated('Use afRelationship instead') String? AFRelationship, String afRelationship = '/Alternative'})

Properties

afRelationship → String
final
data → String
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subType → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited