PdfaFacturxRdf class

Constructors

PdfaFacturxRdf()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({String filename = 'factur-x.xml', String namespace = 'urn:cen.eu:invoice:1p0:schema#', String conformanceLevel = 'BASIC', String version = '1.0'}) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited