PdfaRdf class

Constructors

PdfaRdf({String? title, String? author, String? creator, String? subject, String? keywords, String? producer, DateTime? creationDate, String invoiceRdf = ''})

Properties

author → String?
final
creationDate ↔ DateTime
latefinal
creator → String?
final
hashCode → int
The hash code for this object.
no setterinherited
invoiceRdf → String
final
keywords → String?
final
producer → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
final
title → String?
final

Methods

create() → XmlDocument?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited