TtfBitmapInfo class

Constructors

TtfBitmapInfo(Uint8List data, int height, int width, int horiBearingX, int horiBearingY, int horiAdvance, int vertBearingX, int vertBearingY, int vertAdvance, int ascent, int descent)
const

Properties

ascent → int
final
data → Uint8List
final
descent → int
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
final
horiAdvance → int
final
horiBearingX → int
final
horiBearingY → int
final
metrics → PdfFontMetrics
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vertAdvance → int
final
vertBearingX → int
final
vertBearingY → int
final
width → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited