TtfGlyphInfo class

Annotations
  • @immutable

Constructors

TtfGlyphInfo(int index, Uint8List data, List<int> compounds)
const

Properties

compounds → List<int>
final
data → Uint8List
final
hashCode → int
The hash code for this object.
no setterinherited
index → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → TtfGlyphInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited