TtfParser class

Constructors

TtfParser(ByteData bytes)

Properties

ascent → int
no setter
bitmapOffsets → Map<int, TtfBitmapInfo>
final
bytes → ByteData
final
charToGlyphIndexMap → Map<int, int>
final
descent → int
no setter
fontName → String
no setter
glyphInfoMap → Map<int, PdfFontMetrics>
final
glyphOffsets → List<int>
final
glyphSizes → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
indexToLocFormat → int
no setter
isBitmap → bool
no setter
lineGap → int
no setter
numGlyphs → int
no setter
numOfLongHorMetrics → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableOffsets → Map<String, int>
final
tableSize → Map<String, int>
final
unicode → bool
no setter
unitsPerEm → int
no setter
xMax → int
no setter
xMin → int
no setter
yMax → int
no setter
yMin → int
no setter

Methods

getBitmap(int charcode) → TtfBitmapInfo?
getNameID(TtfParserName fontNameID) → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readGlyph(int index) → TtfGlyphInfo
http://stevehanov.ca/blog/?id=143
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

cbdt_table → const String
cblc_table → const String
cmap_table → const String
glyf_table → const String
head_table → const String
hhea_table → const String
hmtx_table → const String
loca_table → const String
maxp_table → const String
name_table → const String
os_2_table → const String
post_table → const String