PdfJpegInfo class
Jpeg metadata extraction
Constructors
- PdfJpegInfo(Uint8List image)
-
Load a Jpeg image's metadata
factory
Properties
- exifVersion → String?
-
EXIF version
no setter
- flashpixVersion → String?
-
Flashpix format version
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
Height of the image
final
- isCMYK → bool
-
Whether the image uses CMYK color space (4 components)
no setter
- isCMYKInverted → bool
-
Whether this CMYK JPEG uses inverted color values (Adobe YCCK convention).
Returns true when there is no Adobe APP14 marker (assumed inverted, the
most common case) or when the marker explicitly indicates YCCK encoding.
no setter
- isRGB → bool
-
Is the image color or greyscale
no setter
- orientation → PdfImageOrientation
-
Rotation angle of this image
no setter
- pixelXDimension → int?
-
Exif horizontal pixel dimension
no setter
- pixelYDimension → int?
-
Exif vertical pixel dimension
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Exif tags discovered
final
- width → int?
-
Width of the image
final
- xResolution → double?
-
Exif horizontal resolution
no setter
- yResolution → double?
-
Exif vertical resolution
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited